@@ -405,7 +405,11 @@ on_mini_drawingarea_configure_event    (GtkWidget       *widget,
 			       widget->allocation.width,
 			       widget->allocation.height, -1);
 
-  draw_string_to_mini_window("Input ID");
+  if (auto_flag != 0) {
+    draw_string_to_mini_window("Input ID");
+  } else {
+    draw_string_to_mini_window("Connect");
+  }
 
   return TRUE;
 }
@@ -437,16 +441,18 @@ draw_string_to_mini_window(char *string)
   GdkGC *gc;
   GdkColor color;
 
-  gc = mini_drawingarea->style->white_gc;
-  gdk_draw_rectangle(mini_pixmap, gc, TRUE,
-		     0, 0, mini_drawingarea->allocation.width, mini_drawingarea->allocation.height);
-  gdk_draw_string(mini_pixmap, font, mini_drawingarea->style->black_gc, 1, 20, string);
+  if (notice_flag == 1) {
+    gc = mini_drawingarea->style->white_gc;
+    gdk_draw_rectangle(mini_pixmap, gc, TRUE,
+		       0, 0, mini_drawingarea->allocation.width, mini_drawingarea->allocation.height);
+    gdk_draw_string(mini_pixmap, font, mini_drawingarea->style->black_gc, 1, 20, string);
 
-  gdkrect.x = 0;
-  gdkrect.y = 0;
-  gdkrect.width = mini_drawingarea->allocation.width;
-  gdkrect.height = mini_drawingarea->allocation.height;
-  gtk_widget_draw(mini_drawingarea, &gdkrect);
+    gdkrect.x = 0;
+    gdkrect.y = 0;
+    gdkrect.width = mini_drawingarea->allocation.width;
+    gdkrect.height = mini_drawingarea->allocation.height;
+    gtk_widget_draw(mini_drawingarea, &gdkrect);
+  }
 }
 
 
