@@ -66,6 +66,7 @@ GtkWidget *dialog_send_comboboxentry2;
 extern GtkWidget *dialog_send_viewport1;
 extern GtkWidget *dialog_send_viewport2;
 extern GtkWidget *dialog_send_hbox;
+char fullscreen_flag;
 
 extern GtkWidget *dialog_IDinput;
 char server_name[16];
@@ -299,6 +300,7 @@ on_send_activate                       (GtkMenuItem     *menuitem,
     send_state_tmp[Cnt] = GETSEND(Cnt);
     if (server_CB.user_num == ++user_cnt) break;
   }
+  fullscreen_flag = 1;
 
   dialog_send = create_dialog_send();
 
@@ -1786,7 +1788,7 @@ send_start(void)
     if (server_CB.client_grp[c_num] == NULL) continue;
     if ((!recv_state_tmp[c_num] && GETRECV(c_num)) || (recv_state_tmp[c_num] && !GETRECV(c_num))) {
       SETRECV(c_num, recv_state_tmp[c_num]);
-      SendCastMsg(GETRECV(c_num), c_num);
+      SendCastMsg(GETRECV(c_num), c_num, fullscreen_flag);
     }
     if (server_CB.user_num == ++user_cnt) break;
   }
@@ -2009,7 +2011,7 @@ on_dialog_sendstop_buttonOK_clicked            (GtkButton       *button,
   int c_num = (int)user_data;
 
   SETRECV(c_num, FALSE);
-  SendCastMsg(FALSE, c_num);
+  SendCastMsg(FALSE, c_num, fullscreen_flag);
 
   gtk_grab_remove(dialog_sendstop);
   gtk_widget_destroy(dialog_sendstop);
@@ -2139,3 +2141,21 @@ on_dialog_version_buttonOK_clicked     (GtkButton       *button,
   gtk_widget_destroy(dialog_version);
 }
 
+
+void
+on_dialog_send_fullscreen_radiobutton_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+  fullscreen_flag = 1;
+}
+
+
+void
+on_dialog_send_window_radiobutton_toggled
+                                        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+  fullscreen_flag = 0;
+}
+
